@@ -94,52 +94,52 @@ INPUTS = {
 
 RECIPE = {
   'setup': {
-    'day': [
-      'Mon'
-    ],
     'hour': [
       3
+    ],
+    'day': [
+      'Mon'
     ]
   },
   'tasks': [
     {
       'drive': {
         'auth': 'user',
+        'hour': [
+        ],
         'copy': {
+          'source': 'https://docs.google.com/spreadsheets/d/1rH_PGXOYW2mVdmAYnKbv6kcaB6lQihAyMsGtFfinnqg/',
           'destination': {
             'field': {
-              'default': '',
-              'description': 'Name of document to deploy to.',
-              'kind': 'string',
               'name': 'recipe_name',
+              'prefix': 'ITP Audit ',
+              'kind': 'string',
               'order': 1,
-              'prefix': 'ITP Audit '
+              'description': 'Name of document to deploy to.',
+              'default': ''
             }
-          },
-          'source': 'https://docs.google.com/spreadsheets/d/1rH_PGXOYW2mVdmAYnKbv6kcaB6lQihAyMsGtFfinnqg/'
-        },
-        'hour': [
-        ]
+          }
+        }
       }
     },
     {
       'dataset': {
         'auth': {
           'field': {
-            'default': 'service',
-            'description': 'Credentials used for writing data.',
-            'kind': 'authentication',
             'name': 'auth_write',
-            'order': 1
+            'kind': 'authentication',
+            'order': 1,
+            'default': 'service',
+            'description': 'Credentials used for writing data.'
           }
         },
         'dataset': {
           'field': {
-            'default': 'ITP_Audit_Dashboard',
-            'description': 'BigQuery dataset for store dashboard tables.',
-            'kind': 'string',
             'name': 'recipe_slug',
-            'order': 1
+            'kind': 'string',
+            'order': 1,
+            'default': 'ITP_Audit_Dashboard',
+            'description': 'BigQuery dataset for store dashboard tables.'
           }
         }
       }
@@ -148,19 +148,64 @@ RECIPE = {
       'dbm': {
         'auth': {
           'field': {
-            'default': 'user',
-            'description': 'Credentials used for reading data.',
-            'kind': 'authentication',
             'name': 'auth_read',
-            'order': 1
+            'kind': 'authentication',
+            'order': 1,
+            'default': 'user',
+            'description': 'Credentials used for reading data.'
           }
         },
-        'delete': False,
         'report': {
+          'timeout': 90,
+          'filters': {
+            'FILTER_ADVERTISER': {
+              'values': {
+                'field': {
+                  'name': 'dv360_advertiser_ids',
+                  'kind': 'integer_list',
+                  'order': 6,
+                  'default': '',
+                  'description': 'Optional: Comma delimited list of DV360 Advertiser ids.'
+                }
+              }
+            },
+            'FILTER_PARTNER': {
+              'values': {
+                'field': {
+                  'name': 'dv360_partner_ids',
+                  'kind': 'integer_list',
+                  'order': 5,
+                  'default': '',
+                  'description': 'Comma delimited list of DV360 Partner ids.'
+                }
+              }
+            }
+          },
           'body': {
+            'timezoneCode': {
+              'field': {
+                'name': 'recipe_timezone',
+                'kind': 'timezone',
+                'description': 'Timezone for report dates.',
+                'default': 'America/Los_Angeles'
+              }
+            },
             'metadata': {
+              'title': {
+                'field': {
+                  'name': 'recipe_name',
+                  'kind': 'string',
+                  'prefix': 'ITP_Audit_Browser_',
+                  'order': 1,
+                  'description': 'Name of report in DV360, should be unique.'
+                }
+              },
               'dataRange': {
                 'field': {
+                  'name': 'date_range',
+                  'kind': 'choice',
+                  'order': 3,
+                  'default': 'LAST_365_DAYS',
                   'choices': [
                     'LAST_7_DAYS',
                     'LAST_14_DAYS',
@@ -178,25 +223,13 @@ RECIPE = {
                     'WEEK_TO_DATE',
                     'YEAR_TO_DATE'
                   ],
-                  'default': 'LAST_365_DAYS',
-                  'description': 'Timeframe to run the ITP report for.',
-                  'kind': 'choice',
-                  'name': 'date_range',
-                  'order': 3
+                  'description': 'Timeframe to run the ITP report for.'
                 }
               },
-              'format': 'CSV',
-              'title': {
-                'field': {
-                  'description': 'Name of report in DV360, should be unique.',
-                  'kind': 'string',
-                  'name': 'recipe_name',
-                  'order': 1,
-                  'prefix': 'ITP_Audit_Browser_'
-                }
-              }
+              'format': 'CSV'
             },
             'params': {
+              'type': 'TYPE_GENERAL',
               'groupBys': [
                 'FILTER_PARTNER',
                 'FILTER_PARTNER_NAME',
@@ -227,92 +260,71 @@ RECIPE = {
                 'METRIC_CM_POST_CLICK_REVENUE',
                 'METRIC_CM_POST_VIEW_REVENUE',
                 'METRIC_REVENUE_ADVERTISER'
-              ],
-              'type': 'TYPE_GENERAL'
-            },
-            'timezoneCode': {
-              'field': {
-                'default': 'America/Los_Angeles',
-                'description': 'Timezone for report dates.',
-                'kind': 'timezone',
-                'name': 'recipe_timezone'
-              }
+              ]
             }
-          },
-          'filters': {
-            'FILTER_ADVERTISER': {
-              'values': {
-                'field': {
-                  'default': '',
-                  'description': 'Optional: Comma delimited list of DV360 Advertiser ids.',
-                  'kind': 'integer_list',
-                  'name': 'dv360_advertiser_ids',
-                  'order': 6
-                }
-              }
-            },
-            'FILTER_PARTNER': {
-              'values': {
-                'field': {
-                  'default': '',
-                  'description': 'Comma delimited list of DV360 Partner ids.',
-                  'kind': 'integer_list',
-                  'name': 'dv360_partner_ids',
-                  'order': 5
-                }
-              }
-            }
-          },
-          'timeout': 90
-        }
+          }
+        },
+        'delete': False
       }
     },
     {
       'dcm': {
         'auth': {
           'field': {
-            'default': 'user',
-            'description': 'Credentials used for reading data.',
-            'kind': 'authentication',
             'name': 'auth_read',
-            'order': 1
-          }
-        },
-        'delete': False,
-        'out': {
-          'bigquery': {
-            'dataset': {
-              'field': {
-                'default': 'ITP_Audit_Dashboard',
-                'description': 'BigQuery dataset for store dashboard tables.',
-                'kind': 'string',
-                'name': 'recipe_slug',
-                'order': 1
-              }
-            },
-            'is_incremental_load': False,
-            'table': 'z_Floodlight_CM_Report'
+            'kind': 'authentication',
+            'order': 1,
+            'default': 'user',
+            'description': 'Credentials used for reading data.'
           }
         },
         'report': {
+          'timeout': 90,
           'account': {
             'field': {
-              'default': '',
-              'description': 'Campaign Manager Account Id.',
-              'kind': 'string',
               'name': 'cm_account_id',
-              'order': 2
+              'kind': 'string',
+              'order': 2,
+              'default': '',
+              'description': 'Campaign Manager Account Id.'
             }
           },
           'body': {
-            'delivery': {
-              'emailOwner': False
+            'kind': 'dfareporting#report',
+            'name': {
+              'field': {
+                'name': 'recipe_name',
+                'kind': 'string',
+                'prefix': 'ITP_Audit_Floodlight_',
+                'order': 1,
+                'description': 'Name of report in DV360, should be unique.'
+              }
             },
+            'format': 'CSV',
+            'type': 'FLOODLIGHT',
             'floodlightCriteria': {
               'dateRange': {
                 'kind': 'dfareporting#dateRange',
                 'relativeDateRange': 'LAST_30_DAYS'
               },
+              'floodlightConfigId': {
+                'kind': 'dfareporting#dimensionValue',
+                'dimensionName': 'dfa:floodlightConfigId',
+                'value': {
+                  'field': {
+                    'name': 'floodlight_configuration_id',
+                    'kind': 'integer',
+                    'order': 4,
+                    'default': '',
+                    'description': 'Floodlight Configuration Id for the Campaign Manager floodlight report.'
+                  }
+                },
+                'matchType': 'EXACT'
+              },
+              'reportProperties': {
+                'includeUnattributedIPConversions': False,
+                'includeUnattributedCookieConversions': True
+              },
               'dimensions': [
                 {
                   'kind': 'dfareporting#sortedDimension',
@@ -343,99 +355,112 @@ RECIPE = {
                   'name': 'dfa:week'
                 }
               ],
-              'floodlightConfigId': {
-                'dimensionName': 'dfa:floodlightConfigId',
-                'kind': 'dfareporting#dimensionValue',
-                'matchType': 'EXACT',
-                'value': {
-                  'field': {
-                    'default': '',
-                    'description': 'Floodlight Configuration Id for the Campaign Manager floodlight report.',
-                    'kind': 'integer',
-                    'name': 'floodlight_configuration_id',
-                    'order': 4
-                  }
-                }
-              },
               'metricNames': [
                 'dfa:activityClickThroughConversions',
                 'dfa:activityViewThroughConversions',
                 'dfa:totalConversions',
                 'dfa:totalConversionsRevenue'
-              ],
-              'reportProperties': {
-                'includeUnattributedCookieConversions': True,
-                'includeUnattributedIPConversions': False
-              }
-            },
-            'format': 'CSV',
-            'kind': 'dfareporting#report',
-            'name': {
-              'field': {
-                'description': 'Name of report in DV360, should be unique.',
-                'kind': 'string',
-                'name': 'recipe_name',
-                'order': 1,
-                'prefix': 'ITP_Audit_Floodlight_'
-              }
+              ]
             },
             'schedule': {
               'active': True,
-              'every': 1,
               'repeats': 'WEEKLY',
+              'every': 1,
               'repeatsOnWeekDays': [
                 'Sunday'
               ]
             },
-            'type': 'FLOODLIGHT'
-          },
-          'timeout': 90
-        }
+            'delivery': {
+              'emailOwner': False
+            }
+          }
+        },
+        'out': {
+          'bigquery': {
+            'dataset': {
+              'field': {
+                'name': 'recipe_slug',
+                'kind': 'string',
+                'order': 1,
+                'default': 'ITP_Audit_Dashboard',
+                'description': 'BigQuery dataset for store dashboard tables.'
+              }
+            },
+            'table': 'z_Floodlight_CM_Report',
+            'is_incremental_load': False
+          }
+        },
+        'delete': False
       }
     },
     {
       'dcm': {
         'auth': {
           'field': {
-            'default': 'user',
-            'description': 'Credentials used for reading data.',
-            'kind': 'authentication',
             'name': 'auth_read',
-            'order': 1
-          }
-        },
-        'delete': False,
-        'out': {
-          'bigquery': {
-            'dataset': {
-              'field': {
-                'default': 'ITP_Audit_Dashboard',
-                'description': 'BigQuery dataset for store dashboard tables.',
-                'kind': 'string',
-                'name': 'recipe_slug',
-                'order': 1
-              }
-            },
-            'is_incremental_load': False,
-            'table': 'z_CM_Browser_Report_Dirty'
+            'kind': 'authentication',
+            'order': 1,
+            'default': 'user',
+            'description': 'Credentials used for reading data.'
           }
         },
         'report': {
+          'timeout': 90,
           'account': {
             'field': {
-              'default': '',
-              'description': 'Campaign Manager Account Id.',
-              'kind': 'string',
               'name': 'cm_account_id',
-              'order': 2
+              'kind': 'string',
+              'order': 2,
+              'default': '',
+              'description': 'Campaign Manager Account Id.'
+            }
+          },
+          'filters': {
+            'dfa:advertiser': {
+              'values': {
+                'field': {
+                  'name': 'cm_advertiser_ids',
+                  'kind': 'integer_list',
+                  'order': 3,
+                  'default': '',
+                  'description': 'Optional: Comma delimited list of CM advertiser ids.'
+                }
+              }
             }
           },
           'body': {
+            'kind': 'dfareporting#report',
+            'name': {
+              'field': {
+                'name': 'recipe_name',
+                'kind': 'string',
+                'order': 1,
+                'prefix': 'ITP_Audit_Browser_',
+                'default': 'ITP_Audit_Dashboard_Browser',
+                'description': 'Name of the Campaign Manager browser report.'
+              }
+            },
+            'fileName': {
+              'field': {
+                'name': 'recipe_name',
+                'kind': 'string',
+                'order': 1,
+                'prefix': 'ITP_Audit_Browser_',
+                'default': 'ITP_Audit_Dashboard_Browser',
+                'description': 'Name of the Campaign Manager browser report.'
+              }
+            },
+            'format': 'CSV',
+            'type': 'STANDARD',
             'criteria': {
               'dateRange': {
                 'kind': 'dfareporting#dateRange',
                 'relativeDateRange': {
                   'field': {
+                    'name': 'date_range',
+                    'kind': 'choice',
+                    'order': 3,
+                    'default': 'LAST_365_DAYS',
                     'choices': [
                       'LAST_7_DAYS',
                       'LAST_14_DAYS',
@@ -453,16 +478,10 @@ RECIPE = {
                       'WEEK_TO_DATE',
                       'YEAR_TO_DATE'
                     ],
-                    'default': 'LAST_365_DAYS',
-                    'description': 'Timeframe to run the ITP report for.',
-                    'kind': 'choice',
-                    'name': 'date_range',
-                    'order': 3
+                    'description': 'Timeframe to run the ITP report for.'
                   }
                 }
               },
-              'dimensionFilters': [
-              ],
               'dimensions': [
                 {
                   'kind': 'dfareporting#sortedDimension',
@@ -507,57 +526,87 @@ RECIPE = {
                 'dfa:totalConversions',
                 'dfa:activityViewThroughConversions',
                 'dfa:activityClickThroughConversions'
+              ],
+              'dimensionFilters': [
               ]
             },
-            'delivery': {
-              'emailOwner': False
-            },
-            'fileName': {
-              'field': {
-                'default': 'ITP_Audit_Dashboard_Browser',
-                'description': 'Name of the Campaign Manager browser report.',
-                'kind': 'string',
-                'name': 'recipe_name',
-                'order': 1,
-                'prefix': 'ITP_Audit_Browser_'
-              }
-            },
-            'format': 'CSV',
-            'kind': 'dfareporting#report',
-            'name': {
-              'field': {
-                'default': 'ITP_Audit_Dashboard_Browser',
-                'description': 'Name of the Campaign Manager browser report.',
-                'kind': 'string',
-                'name': 'recipe_name',
-                'order': 1,
-                'prefix': 'ITP_Audit_Browser_'
-              }
-            },
             'schedule': {
               'active': True,
-              'every': 1,
               'repeats': 'WEEKLY',
+              'every': 1,
               'repeatsOnWeekDays': [
                 'Sunday'
               ]
             },
-            'type': 'STANDARD'
-          },
-          'filters': {
-            'dfa:advertiser': {
-              'values': {
-                'field': {
-                  'default': '',
-                  'description': 'Optional: Comma delimited list of CM advertiser ids.',
-                  'kind': 'integer_list',
-                  'name': 'cm_advertiser_ids',
-                  'order': 3
-                }
+            'delivery': {
+              'emailOwner': False
+            }
+          }
+        },
+        'out': {
+          'bigquery': {
+            'dataset': {
+              'field': {
+                'name': 'recipe_slug',
+                'kind': 'string',
+                'order': 1,
+                'default': 'ITP_Audit_Dashboard',
+                'description': 'BigQuery dataset for store dashboard tables.'
               }
+            },
+            'table': 'z_CM_Browser_Report_Dirty',
+            'is_incremental_load': False
+          }
+        },
+        'delete': False
+      }
+    },
+    {
+      'sheets': {
+        'auth': {
+          'field': {
+            'name': 'auth_read',
+            'kind': 'authentication',
+            'order': 1,
+            'default': 'user',
+            'description': 'Credentials used for reading data.'
+          }
+        },
+        'sheet': {
+          'field': {
+            'name': 'recipe_name',
+            'prefix': 'ITP Audit ',
+            'kind': 'string',
+            'order': 1,
+            'description': 'Name of document to deploy to.',
+            'default': ''
+          }
+        },
+        'tab': 'Enviroment',
+        'range': 'A:B',
+        'header': True,
+        'out': {
+          'auth': {
+            'field': {
+              'name': 'auth_write',
+              'kind': 'authentication',
+              'order': 1,
+              'default': 'service',
+              'description': 'Credentials used for writing data.'
             }
           },
-          'timeout': 90
+          'bigquery': {
+            'dataset': {
+              'field': {
+                'name': 'recipe_slug',
+                'kind': 'string',
+                'order': 1,
+                'default': 'ITP_Audit_Dashboard',
+                'description': 'BigQuery dataset for store dashboard tables.'
+              }
+            },
+            'table': 'z_Environment'
+          }
         }
       }
     },
@@ -565,269 +614,232 @@ RECIPE = {
       'sheets': {
         'auth': {
           'field': {
-            'default': 'user',
-            'description': 'Credentials used for reading data.',
-            'kind': 'authentication',
             'name': 'auth_read',
-            'order': 1
+            'kind': 'authentication',
+            'order': 1,
+            'default': 'user',
+            'description': 'Credentials used for reading data.'
           }
         },
-        'header': True,
-        'out': {
-          'auth': {
-            'field': {
-              'default': 'service',
-              'description': 'Credentials used for writing data.',
-              'kind': 'authentication',
-              'name': 'auth_write',
-              'order': 1
-            }
-          },
-          'bigquery': {
-            'dataset': {
-              'field': {
-                'default': 'ITP_Audit_Dashboard',
-                'description': 'BigQuery dataset for store dashboard tables.',
-                'kind': 'string',
-                'name': 'recipe_slug',
-                'order': 1
-              }
-            },
-            'table': 'z_Environment'
-          }
-        },
-        'range': 'A:B',
         'sheet': {
           'field': {
-            'default': '',
-            'description': 'Name of document to deploy to.',
-            'kind': 'string',
             'name': 'recipe_name',
+            'prefix': 'ITP Audit ',
+            'kind': 'string',
             'order': 1,
-            'prefix': 'ITP Audit '
-          }
-        },
-        'tab': 'Enviroment'
-      }
-    },
-    {
-      'sheets': {
-        'auth': {
-          'field': {
-            'default': 'user',
-            'description': 'Credentials used for reading data.',
-            'kind': 'authentication',
-            'name': 'auth_read',
-            'order': 1
+            'description': 'Name of document to deploy to.',
+            'default': ''
           }
         },
+        'tab': 'Browser',
+        'range': 'A:C',
         'header': True,
         'out': {
           'auth': {
             'field': {
-              'default': 'service',
-              'description': 'Credentials used for writing data.',
-              'kind': 'authentication',
               'name': 'auth_write',
-              'order': 1
+              'kind': 'authentication',
+              'order': 1,
+              'default': 'service',
+              'description': 'Credentials used for writing data.'
             }
           },
           'bigquery': {
             'dataset': {
               'field': {
-                'default': 'ITP_Audit_Dashboard',
-                'description': 'BigQuery dataset for store dashboard tables.',
-                'kind': 'string',
                 'name': 'recipe_slug',
-                'order': 1
+                'kind': 'string',
+                'order': 1,
+                'default': 'ITP_Audit_Dashboard',
+                'description': 'BigQuery dataset for store dashboard tables.'
               }
             },
             'table': 'z_Browser'
           }
-        },
-        'range': 'A:C',
-        'sheet': {
-          'field': {
-            'default': '',
-            'description': 'Name of document to deploy to.',
-            'kind': 'string',
-            'name': 'recipe_name',
-            'order': 1,
-            'prefix': 'ITP Audit '
-          }
-        },
-        'tab': 'Browser'
+        }
       }
     },
     {
       'sheets': {
         'auth': {
           'field': {
-            'default': 'user',
-            'description': 'Credentials used for reading data.',
-            'kind': 'authentication',
             'name': 'auth_read',
-            'order': 1
+            'kind': 'authentication',
+            'order': 1,
+            'default': 'user',
+            'description': 'Credentials used for reading data.'
           }
         },
+        'sheet': {
+          'field': {
+            'name': 'recipe_name',
+            'prefix': 'ITP Audit ',
+            'kind': 'string',
+            'order': 1,
+            'description': 'Name of document to deploy to.',
+            'default': ''
+          }
+        },
+        'tab': 'CM_Browser_lookup',
+        'range': 'A:C',
         'header': True,
         'out': {
           'auth': {
             'field': {
-              'default': 'service',
-              'description': 'Credentials used for writing data.',
-              'kind': 'authentication',
               'name': 'auth_write',
-              'order': 1
+              'kind': 'authentication',
+              'order': 1,
+              'default': 'service',
+              'description': 'Credentials used for writing data.'
             }
           },
           'bigquery': {
             'dataset': {
               'field': {
-                'default': 'ITP_Audit_Dashboard',
-                'description': 'BigQuery dataset for store dashboard tables.',
-                'kind': 'string',
                 'name': 'recipe_slug',
-                'order': 1
+                'kind': 'string',
+                'order': 1,
+                'default': 'ITP_Audit_Dashboard',
+                'description': 'BigQuery dataset for store dashboard tables.'
               }
             },
             'table': 'z_CM_Browser_lookup'
           }
-        },
-        'range': 'A:C',
-        'sheet': {
-          'field': {
-            'default': '',
-            'description': 'Name of document to deploy to.',
-            'kind': 'string',
-            'name': 'recipe_name',
-            'order': 1,
-            'prefix': 'ITP Audit '
-          }
-        },
-        'tab': 'CM_Browser_lookup'
+        }
       }
     },
     {
       'sheets': {
         'auth': {
           'field': {
-            'default': 'user',
-            'description': 'Credentials used for reading data.',
-            'kind': 'authentication',
             'name': 'auth_read',
-            'order': 1
+            'kind': 'authentication',
+            'order': 1,
+            'default': 'user',
+            'description': 'Credentials used for reading data.'
           }
         },
+        'sheet': {
+          'field': {
+            'name': 'recipe_name',
+            'prefix': 'ITP Audit ',
+            'kind': 'string',
+            'order': 1,
+            'description': 'Name of document to deploy to.',
+            'default': ''
+          }
+        },
+        'tab': 'Device_Type',
+        'range': 'A:B',
         'header': True,
         'out': {
           'auth': {
             'field': {
-              'default': 'service',
-              'description': 'Credentials used for writing data.',
-              'kind': 'authentication',
               'name': 'auth_write',
-              'order': 1
+              'kind': 'authentication',
+              'order': 1,
+              'default': 'service',
+              'description': 'Credentials used for writing data.'
             }
           },
           'bigquery': {
             'dataset': {
               'field': {
-                'default': 'ITP_Audit_Dashboard',
-                'description': 'BigQuery dataset for store dashboard tables.',
-                'kind': 'string',
                 'name': 'recipe_slug',
-                'order': 1
+                'kind': 'string',
+                'order': 1,
+                'default': 'ITP_Audit_Dashboard',
+                'description': 'BigQuery dataset for store dashboard tables.'
               }
             },
             'table': 'z_Device_Type'
           }
-        },
-        'range': 'A:B',
-        'sheet': {
-          'field': {
-            'default': '',
-            'description': 'Name of document to deploy to.',
-            'kind': 'string',
-            'name': 'recipe_name',
-            'order': 1,
-            'prefix': 'ITP Audit '
-          }
-        },
-        'tab': 'Device_Type'
+        }
       }
     },
     {
       'sheets': {
         'auth': {
           'field': {
-            'default': 'user',
-            'description': 'Credentials used for reading data.',
-            'kind': 'authentication',
             'name': 'auth_read',
-            'order': 1
+            'kind': 'authentication',
+            'order': 1,
+            'default': 'user',
+            'description': 'Credentials used for reading data.'
           }
         },
+        'sheet': {
+          'field': {
+            'name': 'recipe_name',
+            'prefix': 'ITP Audit ',
+            'kind': 'string',
+            'order': 1,
+            'description': 'Name of document to deploy to.',
+            'default': ''
+          }
+        },
+        'tab': 'Floodlight_Attribution',
+        'range': 'A:B',
         'header': True,
         'out': {
           'auth': {
             'field': {
-              'default': 'service',
-              'description': 'Credentials used for writing data.',
-              'kind': 'authentication',
               'name': 'auth_write',
-              'order': 1
+              'kind': 'authentication',
+              'order': 1,
+              'default': 'service',
+              'description': 'Credentials used for writing data.'
             }
           },
           'bigquery': {
             'dataset': {
               'field': {
-                'default': 'ITP_Audit_Dashboard',
-                'description': 'BigQuery dataset for store dashboard tables.',
-                'kind': 'string',
                 'name': 'recipe_slug',
-                'order': 1
+                'kind': 'string',
+                'order': 1,
+                'default': 'ITP_Audit_Dashboard',
+                'description': 'BigQuery dataset for store dashboard tables.'
               }
             },
             'table': 'z_Floodlight_Attribution'
           }
-        },
-        'range': 'A:B',
-        'sheet': {
-          'field': {
-            'default': '',
-            'description': 'Name of document to deploy to.',
-            'kind': 'string',
-            'name': 'recipe_name',
-            'order': 1,
-            'prefix': 'ITP Audit '
-          }
-        },
-        'tab': 'Floodlight_Attribution'
+        }
       }
     },
     {
       'dbm': {
         'auth': {
           'field': {
-            'default': 'user',
-            'description': 'Credentials used for reading data.',
-            'kind': 'authentication',
             'name': 'auth_read',
-            'order': 1
+            'kind': 'authentication',
+            'order': 1,
+            'default': 'user',
+            'description': 'Credentials used for reading data.'
+          }
+        },
+        'report': {
+          'name': {
+            'field': {
+              'name': 'recipe_name',
+              'kind': 'string',
+              'prefix': 'ITP_Audit_Browser_',
+              'order': 1,
+              'description': 'Name of report in DV360, should be unique.'
+            }
           }
         },
         'out': {
           'bigquery': {
             'dataset': {
               'field': {
-                'default': 'ITP_Audit_Dashboard',
-                'description': 'BigQuery dataset for store dashboard tables.',
-                'kind': 'string',
                 'name': 'recipe_slug',
-                'order': 1
+                'kind': 'string',
+                'order': 1,
+                'default': 'ITP_Audit_Dashboard',
+                'description': 'BigQuery dataset for store dashboard tables.'
               }
             },
+            'table': 'z_Dv360_Browser_Report_Dirty',
             'header': True,
             'schema': [
               {
@@ -875,131 +887,119 @@ RECIPE = {
                 'type': 'STRING'
               },
               {
-                'mode': 'NULLABLE',
                 'name': 'Environment',
-                'type': 'STRING'
+                'type': 'STRING',
+                'mode': 'NULLABLE'
               },
               {
-                'mode': 'NULLABLE',
                 'name': 'Week',
-                'type': 'STRING'
+                'type': 'STRING',
+                'mode': 'NULLABLE'
               },
               {
-                'mode': 'NULLABLE',
                 'name': 'Month',
-                'type': 'STRING'
+                'type': 'STRING',
+                'mode': 'NULLABLE'
               },
               {
-                'mode': 'NULLABLE',
                 'name': 'Year',
-                'type': 'INTEGER'
+                'type': 'INTEGER',
+                'mode': 'NULLABLE'
               },
               {
-                'mode': 'NULLABLE',
                 'name': 'Line_Item_Type',
-                'type': 'STRING'
+                'type': 'STRING',
+                'mode': 'NULLABLE'
               },
               {
-                'mode': 'NULLABLE',
                 'name': 'Device_Type',
-                'type': 'STRING'
+                'type': 'STRING',
+                'mode': 'NULLABLE'
               },
               {
-                'mode': 'NULLABLE',
                 'name': 'Browser',
-                'type': 'STRING'
+                'type': 'STRING',
+                'mode': 'NULLABLE'
               },
               {
-                'mode': 'NULLABLE',
                 'name': 'Media_Cost_Advertiser_Currency',
-                'type': 'FLOAT'
+                'type': 'FLOAT',
+                'mode': 'NULLABLE'
               },
               {
-                'mode': 'NULLABLE',
                 'name': 'Impressions',
-                'type': 'INTEGER'
+                'type': 'INTEGER',
+                'mode': 'NULLABLE'
               },
               {
-                'mode': 'NULLABLE',
                 'name': 'Clicks',
-                'type': 'INTEGER'
+                'type': 'INTEGER',
+                'mode': 'NULLABLE'
               },
               {
-                'mode': 'NULLABLE',
                 'name': 'Total_Conversions',
-                'type': 'FLOAT'
+                'type': 'FLOAT',
+                'mode': 'NULLABLE'
               },
               {
-                'mode': 'NULLABLE',
                 'name': 'Post_Click_Conversions',
-                'type': 'FLOAT'
+                'type': 'FLOAT',
+                'mode': 'NULLABLE'
               },
               {
-                'mode': 'NULLABLE',
                 'name': 'Post_View_Conversions',
-                'type': 'FLOAT'
+                'type': 'FLOAT',
+                'mode': 'NULLABLE'
               },
               {
-                'mode': 'NULLABLE',
                 'name': 'Cm_Post_Click_Revenue',
-                'type': 'FLOAT'
+                'type': 'FLOAT',
+                'mode': 'NULLABLE'
               },
               {
-                'mode': 'NULLABLE',
                 'name': 'Cm_Post_View_Revenue',
-                'type': 'FLOAT'
+                'type': 'FLOAT',
+                'mode': 'NULLABLE'
               },
               {
-                'mode': 'NULLABLE',
                 'name': 'Revenue_Adv_Currency',
-                'type': 'FLOAT'
+                'type': 'FLOAT',
+                'mode': 'NULLABLE'
               }
-            ],
-            'table': 'z_Dv360_Browser_Report_Dirty'
-          }
-        },
-        'report': {
-          'name': {
-            'field': {
-              'description': 'Name of report in DV360, should be unique.',
-              'kind': 'string',
-              'name': 'recipe_name',
-              'order': 1,
-              'prefix': 'ITP_Audit_Browser_'
-            }
+            ]
           }
         }
       }
     },
     {
       'itp_audit': {
+        'auth': 'service',
         'account': {
           'field': {
-            'default': '',
-            'description': 'Campaign Manager Account Id.',
-            'kind': 'string',
             'name': 'cm_account_id',
-            'order': 2
+            'kind': 'string',
+            'order': 2,
+            'default': '',
+            'description': 'Campaign Manager Account Id.'
           }
         },
-        'auth': 'service',
         'dataset': {
           'field': {
-            'default': 'ITP_Audit_Dashboard',
-            'description': 'BigQuery dataset for store dashboard tables.',
-            'kind': 'string',
             'name': 'recipe_slug',
-            'order': 1
+            'kind': 'string',
+            'order': 1,
+            'default': 'ITP_Audit_Dashboard',
+            'description': 'BigQuery dataset for store dashboard tables.'
           }
         },
         'sheet': {
           'field': {
-            'default': '',
-            'description': 'Name of document to deploy to.',
-            'kind': 'string',
             'name': 'recipe_name',
+            'prefix': 'ITP Audit ',
+            'kind': 'string',
             'order': 1,
-            'prefix': 'ITP Audit '
+            'description': 'Name of document to deploy to.',
+            'default': ''
           }
         },
         'timeout': 60
